Repository navigation
cmdhelp
Frank Li edited this page Jan 9, 2025
·
6 revisions
uuu (Universal Update Utility) for nxp imx chips -- libuuu_1.5.191-1-g5d77a61
uuu [-d -m -v -V -bmap -no-bmap] <bootloader|cmdlists|cmd>
bootloader download bootloader to board by usb
cmdlist run all commands in cmdlist file
If it is path, search uuu.auto in dir
If it is zip, search uuu.auto in zip
cmd Run one command, use -H see detail
example: SDPS: boot -f flash.bin
-d Daemon mode, wait for forever.
-v -V verbose mode, -V enable libusb error\warning info
-dry Dry run mode, check if script or cmd correct
-bmap Try using .bmap files even if flash commands do not specify them
-no-bmap Ignore .bmap files even if flash commands specify them
-m <usbpath> Only monitor these paths.
-m 1:2 -m 1:3
-ms <serial_no> Monitor the serial number prefix of the device using 'serial_no'.
-t <timeout> Timeout second for wait known usb device appeared
-T <timeout> Timeout second for wait next known usb device appeared at stage switch
-e <key=value> set environment variable key=value
-pp <ms> usb polling period in milliseconds
-dm disable small memory
uuu -s Enter shell mode. uuu.inputlog record all input commands
you can use "uuu uuu.inputlog" next time to run all commands
uuu -udev linux: show udev rule to avoid sudo each time
uuu -lsusb List connected know devices
uuu -IgSerNum Set windows registry to ignore USB serial number for known uuu devices
uuu -h show general help
uuu -H show general help and detailed help for commands
uuu [-d -m -v -bmap -no-bmap] -b[run] <emmc|emmc_all|fat_write|nand|nvme_all|qspi|sd|sd_all|spi_nand|spl> arg...
Run Built-in scripts
emmc burn boot loader to eMMC boot partition
arg0: _flash.bin bootloader
arg1: _image[Optional] image burn to emmc, default is the same as bootloader
emmc_all burn whole image to eMMC
arg0: _flash.bin bootloader, which can extract from wic image
arg1: _image[Optional] wic image burn to emmc.
fat_write update one file in fat partition, require uboot fastboot running in board
arg0: _image image, which cp to fat partition
arg1: _device storage device, mmc\sata
arg2: _partition fat partition number, like 1:1
arg3: _filename[Optional] file name in target fat partition, only support rootdir now
nand burn boot loader to NAND flash
arg0: _flash.bin bootloader
arg1: _image[Optional] image burn to nand, default is the same as bootloader
nvme_all burn whole image io nvme storage
arg0: _flash.bin bootloader, which can extract from wic image
arg1: _image[Optional] wic image burn to emmc.
qspi burn boot loader to qspi nor flash
arg0: _flexspi.bin bootloader
arg1: _image[Optional] image burn to flexspi, default is the same as bootloader
sd burn boot loader to sd card
arg0: _flash.bin bootloader
arg1: _image[Optional] image burn to emmc, default is the same as bootloader
sd_all burn whole image to sd card
arg0: _flash.bin bootloader, which can extract from wic image
arg1: _image[Optional] wic image burn to emmc.
spi_nand burn boot loader to spi nand flash
arg0: _flexspi.bin bootloader
arg1: _image[Optional] image burn to fspinand, default is the same as bootloader
spl boot spl and uboot
arg0: _flash.bin
uuu -bshow <emmc|emmc_all|fat_write|nand|nvme_all|qspi|sd|sd_all|spi_nand|spl>
Show built-in script....
Notes: Some board supports super speed (USB3.0). USB 3.0 port path is difference USB 2.0. If use -m to filter port, you need add USB 3.0 port number otherwise fastboot will not be detected.
Go back to Home